import { __awaiter, __decorate } from "tslib";
import { Connect } from '@genesislcap/foundation-comms';
import { customElement, FASTElement, observable } from '@microsoft/fast-element';
import { ReportingEventListeners } from '../../routes/reporting-home/types';
import { CreateEditStyles as styles } from './create-edit.styles';
import { CreateEditTemplate as template } from './create-edit.template';
const name = 'reporting-create-edit';
let CreateEdit = class CreateEdit extends FASTElement {
    constructor() {
        super(...arguments);
        this.report = {};
        /**
         * Create report save handle
         */
        this.saveReport = (isEdit, body) => __awaiter(this, void 0, void 0, function* () {
            let notification = null;
            const payload = Object.assign(Object.assign({}, body), { REPORT_COLUMNS: JSON.stringify(body['REPORT_COLUMNS']) });
            const event = isEdit ? 'EVENT_SAVED_REPORTS_UPDATE' : 'EVENT_SAVED_REPORTS_INSERT';
            const result = yield this.connect.commitEvent(event, {
                DETAILS: Object.assign(Object.assign({}, payload), (isEdit ? { REPORT_ID: this.report.REPORT_ID } : {})),
                IGNORE_WARNINGS: true,
                VALIDATE: false,
            });
            if (result.MESSAGE_TYPE === 'EVENT_ACK') {
                notification = {
                    message: `'${body.REPORT_NAME}' was added`,
                    title: 'Success:',
                    type: 'success',
                    autoClose: true,
                };
                this.navigateToListReports();
            }
            else {
                notification = {
                    message: `'${body.REPORT_NAME}' was not added due to the following error "${result.ERROR[0].TEXT}"`,
                    title: 'Error:',
                    type: 'warning',
                    autoClose: true,
                };
            }
            this.$emit(ReportingEventListeners.notify, notification);
        });
    }
    /**
     * Trigger parent event listReports that navigates to list reports tab
     */
    navigateToListReports() {
        this.$emit(ReportingEventListeners.listReports, {});
    }
};
__decorate([
    Connect
], CreateEdit.prototype, "connect", void 0);
__decorate([
    observable
], CreateEdit.prototype, "id", void 0);
__decorate([
    observable
], CreateEdit.prototype, "report", void 0);
__decorate([
    observable
], CreateEdit.prototype, "datasourceSettings", void 0);
CreateEdit = __decorate([
    customElement({
        name,
        template,
        styles,
    })
], CreateEdit);
export { CreateEdit };
