import { formatDateTimestamp } from '@genesislcap/foundation-utils';
import { ColorHEX } from '../../styles';
export var REPORT_FIELDS;
(function (REPORT_FIELDS) {
    REPORT_FIELDS["REPORT_ID"] = "REPORT_ID";
    REPORT_FIELDS["REPORT_NAME"] = "REPORT_NAME";
    REPORT_FIELDS["REPORT_DESCRIPTION"] = "REPORT_DESCRIPTION";
    REPORT_FIELDS["REPORT_DATASOURCE"] = "REPORT_DATASOURCE";
    REPORT_FIELDS["REPORT_COLUMNS"] = "REPORT_COLUMNS";
    REPORT_FIELDS["CREATED_BY"] = "CREATED_BY";
    REPORT_FIELDS["REPORT_CREATED_ON"] = "REPORT_CREATED_ON";
    REPORT_FIELDS["OPTIONS"] = "OPTIONS";
})(REPORT_FIELDS || (REPORT_FIELDS = {}));
export function REPORT_COLUMN_DEFS(context) {
    let retval = [];
    retval = [
        {
            checkboxSelection: true,
            filter: false,
            headerCheckboxSelection: true,
            sortable: false,
            width: 60,
            cellStyle: { display: 'flex' },
        },
        { field: REPORT_FIELDS.REPORT_ID, hide: true },
        { field: REPORT_FIELDS.REPORT_COLUMNS, hide: true },
        {
            field: REPORT_FIELDS.REPORT_NAME,
            headerName: 'Report Name',
            cellStyle: {
                display: 'flex',
                justifyContent: 'flex-start',
                alignItems: 'center',
                textAlign: 'left',
                color: ColorHEX.lightBlue,
            },
            cellRendererSelector: (params) => {
                return {
                    component: 'action',
                    params: {
                        actionClick: () => { var _a; return context.runReport((_a = params === null || params === void 0 ? void 0 : params.node) === null || _a === void 0 ? void 0 : _a.data); },
                        actionName: params === null || params === void 0 ? void 0 : params.value,
                        appearance: 'lightweight',
                    },
                };
            },
        },
        { field: REPORT_FIELDS.REPORT_DESCRIPTION, headerName: 'Description', width: 400 },
        { field: REPORT_FIELDS.REPORT_DATASOURCE, headerName: 'Datasource' },
        { field: REPORT_FIELDS.CREATED_BY, headerName: 'Author' },
        {
            field: REPORT_FIELDS.REPORT_CREATED_ON,
            headerName: 'Created date',
            filter: 'agDateColumnFilter',
            filterParams: {
                comparator: (filterLocalDateAtMidnight, cellValue) => {
                    if (!cellValue)
                        return -1;
                    const cellValueTime = new Date(cellValue).setHours(0, 0, 0, 0);
                    const filterValueTime = filterLocalDateAtMidnight.getTime();
                    if (cellValueTime === filterValueTime) {
                        return 0;
                    }
                    if (cellValueTime < filterValueTime) {
                        return -1;
                    }
                    if (cellValueTime > filterValueTime) {
                        return 1;
                    }
                },
                buttons: ['reset', 'apply'],
                closeOnApply: true,
                closeOnClear: true,
                suppressAndOrCondition: true,
                browserDatePicker: true,
                filterOptions: ['equals', 'lessThan', 'greaterThan'],
            },
            valueFormatter: (rowData) => formatDateTimestamp(rowData.data.REPORT_CREATED_ON),
        },
        {
            width: 100,
            headerName: 'Actions',
            filter: false,
            resizable: false,
            sortable: false,
            cellStyle: {
                display: 'flex',
                justifyContent: 'flex-end',
                alignItems: 'center',
            },
            cellRendererSelector: (params) => {
                return {
                    component: 'action',
                    params: {
                        actionClick: () => { var _a; return context.runReport((_a = params === null || params === void 0 ? void 0 : params.node) === null || _a === void 0 ? void 0 : _a.data); },
                        actionName: 'Run',
                        appearance: 'primary-gradient',
                    },
                };
            },
        },
    ];
    return retval;
}
export function SELECTED_COLUMN_DEFS(context) { }
