import { __awaiter, __decorate } from "tslib";
import { Connect } from '@genesislcap/foundation-comms';
import { ZeroAgTextRenderer } from '@genesislcap/foundation-zero-grid-pro';
import { customElement, FASTElement, observable, attr } from '@microsoft/fast-element';
import { filterObjectArray, getSelectedFields } from '../../utils';
import { FIELD_SELECT_CONFIG, SELECTED_FIELDS_CONFIG } from './columns';
import { SelectFieldsStyles } from './select-fields.styles';
import { SelectFieldsTemplate } from './select-fields.template';
let SelectFields = class SelectFields extends FASTElement {
    constructor() {
        super(...arguments);
        this.fieldsToRemove = [];
        this.report = {};
        this.selectedDatasource = '';
        /**
         * As the current fieldsGrid does not have display name ctx, we need to make sure the text renderer field value is not lost
         * @param array Array
         * @returns Array
         */
        this.makeSureFieldValueIsNotLost = (array) => {
            return array.map((field) => {
                var _a;
                const matchingField = (_a = this.selectedFields) === null || _a === void 0 ? void 0 : _a.find((f) => (f === null || f === void 0 ? void 0 : f.name) === (field === null || field === void 0 ? void 0 : field.name));
                return Object.assign(Object.assign({}, field), matchingField);
            });
        };
        /**
         * When text renderer text field changes handle
         * @param value string
         * @param params Object
         */
        this.onTextFieldChange = (value, params) => __awaiter(this, void 0, void 0, function* () {
            const newFields = this.selectedFields.map((field) => {
                let newField = Object.assign({}, field);
                if (field.name === params.node.data.name) {
                    newField = Object.assign(Object.assign({}, newField), { displayName: value });
                }
                return newField;
            });
            this.setSelectedFields(newFields);
        });
        /**
         * Refresh select field grid data
         */
        this.refreshSelectFieldGridData = () => {
            const selectedFieldsOrder = [];
            this.selectedFieldsGrid.gridApi.forEachNodeAfterFilterAndSort((rowNode) => {
                selectedFieldsOrder.push(rowNode.data);
            });
            this.setSelectedFields([...this.makeSureFieldValueIsNotLost(selectedFieldsOrder)]);
        };
        /**
         * Remove fields from selected fields grid and deselect them from the available fields grid
         */
        this.removeSelectedFields = () => {
            // filter fields from selected list
            const filteredFields = filterObjectArray('name', this.selectedFields, this.fieldsToRemove);
            this.setSelectedFields(filteredFields);
            // reset removal array
            this.fieldsToRemove = [];
            // deselect available fieldgrid
            this.allFieldsGrid.gridApi.deselectAll();
            // reselect
            this.allFieldsGrid.gridApi.forEachNode((node) => {
                filteredFields.find((field) => field.name === node.data.name) && node.setSelected(true);
            });
        };
    }
    /**
     * Loading selected fields grid when we have selected rows
     */
    selectedFieldsChanged(oldValue) {
        var _a, _b, _c, _d;
        if (oldValue) {
            (_b = (_a = this.selectedFieldsGrid) === null || _a === void 0 ? void 0 : _a.gridApi) === null || _b === void 0 ? void 0 : _b.setRowData(this.selectedFields);
            (_d = (_c = this.selectedFieldsGrid) === null || _c === void 0 ? void 0 : _c.gridApi) === null || _d === void 0 ? void 0 : _d.refreshCells();
        }
    }
    connectedCallback() {
        super.connectedCallback();
        this.loadAllFieldsGrid();
        this.loadSelectedFieldsGrid();
    }
    /**
     * Update selected fields on parent component
     */
    setSelectedFields(fields) {
        this.$emit('setSelectedFields', { fields });
    }
    /**
     * Loads the allFieldsGrid
     */
    loadAllFieldsGrid() {
        return __awaiter(this, void 0, void 0, function* () {
            this.allFieldsGrid.gridOptions = Object.assign(Object.assign({}, FIELD_SELECT_CONFIG.gridOptions), { columnDefs: FIELD_SELECT_CONFIG.colDefs, rowData: [...this.fieldData], onSelectionChanged: () => {
                    if (this.selectedFields) {
                        this.selectedFields = getSelectedFields(this.allFieldsGrid, this.selectedFields);
                        this.setSelectedFields([...this.makeSureFieldValueIsNotLost(this.selectedFields)]);
                    }
                    else {
                        this.setSelectedFields([
                            ...this.makeSureFieldValueIsNotLost(this.allFieldsGrid.gridApi.getSelectedRows()),
                        ]);
                    }
                }, onFirstDataRendered: () => {
                    var _a, _b;
                    (_b = (_a = this.allFieldsGrid) === null || _a === void 0 ? void 0 : _a.gridApi) === null || _b === void 0 ? void 0 : _b.sizeColumnsToFit();
                    this.selectDefaultFields();
                }, onGridReady: () => {
                    window.addEventListener('resize', () => {
                        setTimeout(() => {
                            var _a, _b;
                            (_b = (_a = this.allFieldsGrid) === null || _a === void 0 ? void 0 : _a.gridApi) === null || _b === void 0 ? void 0 : _b.sizeColumnsToFit();
                        });
                    });
                } });
        });
    }
    /**
     * Loads the allFieldsGrid
     */
    loadSelectedFieldsGrid() {
        return __awaiter(this, void 0, void 0, function* () {
            this.selectedFieldsGrid.gridOptions = Object.assign(Object.assign({}, SELECTED_FIELDS_CONFIG.gridOptions), { onRowDragEnd: this.refreshSelectFieldGridData, columnDefs: [
                    ...SELECTED_FIELDS_CONFIG.colDefs,
                    {
                        field: 'displayName',
                        headerName: 'Display name',
                        cellRenderer: ZeroAgTextRenderer,
                        cellRendererParams: {
                            accessor: 'displayName',
                            onChange: this.onTextFieldChange,
                        },
                    },
                    {
                        rowDrag: true,
                        width: 60,
                        sortable: false,
                        filter: false,
                    },
                ], rowData: [], onGridReady: () => {
                    window.addEventListener('resize', () => {
                        setTimeout(() => {
                            var _a, _b;
                            (_b = (_a = this.selectedFieldsGrid) === null || _a === void 0 ? void 0 : _a.gridApi) === null || _b === void 0 ? void 0 : _b.sizeColumnsToFit();
                        });
                    });
                }, onFirstDataRendered: () => {
                    var _a, _b;
                    (_b = (_a = this.selectedFieldsGrid) === null || _a === void 0 ? void 0 : _a.gridApi) === null || _b === void 0 ? void 0 : _b.sizeColumnsToFit();
                }, onSelectionChanged: () => {
                    this.fieldsToRemove = this.selectedFieldsGrid.gridApi.getSelectedRows();
                } });
        });
    }
    /**
     * Select default fields
     */
    selectDefaultFields() {
        if (this.selectedFields.length) {
            this.allFieldsGrid.gridApi.forEachNode((node) => {
                this.selectedFields.find((field) => field.name === node.data.name) &&
                    node.setSelected(true);
            });
            this.setSelectedFields([...this.makeSureFieldValueIsNotLost(this.selectedFields)]);
        }
        else {
            this.selectedFields = [];
        }
    }
};
__decorate([
    Connect
], SelectFields.prototype, "connect", void 0);
__decorate([
    observable
], SelectFields.prototype, "fieldsToRemove", void 0);
__decorate([
    observable
], SelectFields.prototype, "fieldData", void 0);
__decorate([
    observable
], SelectFields.prototype, "report", void 0);
__decorate([
    observable
], SelectFields.prototype, "selectedFields", void 0);
__decorate([
    attr
], SelectFields.prototype, "selectedDatasource", void 0);
SelectFields = __decorate([
    customElement({
        name: 'reporting-select-fields',
        template: SelectFieldsTemplate,
        styles: SelectFieldsStyles,
    })
], SelectFields);
export { SelectFields };
