import { __awaiter, __decorate } from "tslib";
import { Session } from '@genesislcap/foundation-comms';
import { customElement, FASTElement, observable } from '@microsoft/fast-element';
import { Container, inject, Registration } from '@microsoft/fast-foundation';
import { DefaultRouteRecognizer } from '@microsoft/fast-router';
import * as Components from '../components';
import { MainRouterConfig } from '../routes';
import { logger } from '../utils';
import { MainStyles as styles } from './main.styles';
import { LoadingTemplate, MainTemplate, MainTemplate as template } from './main.template';
const name = 'foundation-reporting';
/**
 * @deprecated - Use '\@genesislcap/pbc-reporting-ui' instead.
 * 'https://www.npmjs.com/package/\@genesislcap/pbc-reporting-ui'
 * @public
 */
let Reporting = class Reporting extends FASTElement {
    constructor() {
        super(...arguments);
        this.ready = false;
        this.data = null;
    }
    connectedCallback() {
        this.container.register(Registration.transient(DefaultRouteRecognizer, DefaultRouteRecognizer));
        super.connectedCallback();
        logger.debug(`${name} is now connected to the DOM`);
        this.loadRemotes();
        this.checkForSSOToken();
    }
    checkForSSOToken() {
        const queryParams = new URLSearchParams(window.location.search);
        const ssoToken = queryParams.get('SSO_TOKEN');
        if (ssoToken) {
            this.session.setSessionStorageItem('ssoToken', ssoToken);
        }
    }
    loadRemotes() {
        return __awaiter(this, void 0, void 0, function* () {
            /**
             * Send event to indicate some async work is happening. Will be picked up by overlay micro frontend.
             */
            const remoteComponents = yield Components.loadRemotes({});
            /**
             * Simulate loading delay, TODO: Remove
             *
             * await new Promise(resolve => setTimeout(resolve, 3000));
             */
            this.ready = true;
        });
    }
    selectTemplate() {
        return this.ready ? MainTemplate : LoadingTemplate;
    }
    providerChanged() {
        /**
         * Configure foundation ui design system provider if needed
         */
    }
};
__decorate([
    inject(MainRouterConfig)
], Reporting.prototype, "config", void 0);
__decorate([
    Container
], Reporting.prototype, "container", void 0);
__decorate([
    Session
], Reporting.prototype, "session", void 0);
__decorate([
    observable
], Reporting.prototype, "provider", void 0);
__decorate([
    observable
], Reporting.prototype, "ready", void 0);
__decorate([
    observable
], Reporting.prototype, "data", void 0);
Reporting = __decorate([
    customElement({
        name,
        template,
        styles,
    })
], Reporting);
export { Reporting };
