import { __decorate, __param } from "tslib";
import { Auth, Session, FoundationAnalytics, FoundationAnalyticsEventType, } from '@genesislcap/foundation-comms';
import { Container } from '@microsoft/fast-foundation';
import { RouterConfiguration, Route } from '@microsoft/fast-router';
import { defaultLayout } from '../layouts';
import { NotFound } from './not-found/not-found';
import { Protected } from './protected/protected';
import { ReportingHome } from './reporting-home/reporting-home';
/**
 * @deprecated - Reporting MF has been moved to a standalone repo
 * https://github.com/genesislcap/reporting-server/tree/master/client
 * @public
 */
let MainRouterConfig = class MainRouterConfig extends RouterConfiguration {
    constructor(auth, container, analytics, session) {
        super();
        this.auth = auth;
        this.container = container;
        this.analytics = analytics;
        this.session = session;
    }
    configure() {
        this.title = 'Reporting';
        this.defaultLayout = defaultLayout;
        this.routes.map({
            path: '',
            element: ReportingHome,
            title: 'Reporting',
            name: 'reporting-home',
            settings: {
                public: true,
                resetPassword: true,
                forgotPassword: true,
                requestAccount: true,
            },
        }, { path: 'protected', element: Protected, title: 'Protected', name: 'protected' }, { path: 'not-found', element: NotFound, title: 'Not Found', name: 'not-found' });
        const session = this.session;
        const auth = this.auth;
        const analytics = this.analytics;
        /**
         * Example of a FallbackRouteDefinition
         */
        this.routes.fallback(() => auth.isLoggedIn ? { redirect: 'not-found' } : { redirect: 'reporting-home' });
        /**
         * Example of a NavigationContributor
         */
        this.contributors.push({
            navigate: (phase) => {
                const settings = phase.route.settings;
                /**
                 * TODO: Centralise
                 * Suspect this should be done via createEventSink, but it's not fully clear how-to do that as no docs
                 */
                analytics.trackEvent(FoundationAnalyticsEventType.routeChanged, {
                    path: phase.route.endpoint.path,
                });
                /**
                 * If public route don't block
                 */
                if (settings && settings.public) {
                    return;
                }
                /**
                 * If logged in don't block
                 */
                if (auth.isLoggedIn) {
                    return;
                }
                /**
                 * Otherwise route them to login
                 */
                phase.cancel(() => {
                    session.captureReturnUrl();
                    Route.name.replace(phase.router, 'reporting-home');
                });
            },
        });
    }
    construct(Type) {
        return this.container.get(Type);
    }
};
MainRouterConfig = __decorate([
    __param(0, Auth),
    __param(1, Container),
    __param(2, FoundationAnalytics),
    __param(3, Session)
], MainRouterConfig);
export { MainRouterConfig };
