import { html, repeat, ref, when } from '@microsoft/fast-element';
const notificationToast = html `
  <div class="notification-container" data-test-id="notification-container">
    ${repeat((x) => x.notifications, html `
        <zero-toast
          notify=${(notification) => notification.type}
          auto-close=${(notification) => notification.autoClose}
          data-test-id="toast"
        >
          <div slot="top" data-test-id="toast-title">${(notification) => notification.title}</div>
          <p slot="content" data-test-id="toast-message">
            ${(notification) => notification.message}
          </p>
        </zero-toast>
      `)}
  </div>
`;
const header = html `
  <div class="header" data-test-id="header">
    <h1 id="title" class="title" data-test-id="report-title">All Reports</h1>
    <div class="controls" data-test-id="controls">
      <zero-button
        appearance="neutral-grey"
        class="button"
        ?disabled=${(x) => !x.selectedRows.length}
        @click=${(x) => x.reportsGrid.batchDelete()}
        data-test-id="delete-reports-button"
      >
        Delete Reports
      </zero-button>

      <zero-button
        appearance="primary-gradient"
        class="button"
        @click=${(x) => x.create()}
        data-test-id="add-report-button"
      >
        Add new report
      </zero-button>
    </div>
  </div>
`;
export const ReportingHomeTemplate = html `
  ${when((x) => x.notifications.length, notificationToast)}

  <div class="container" data-test-id="reporting-home">
    <zero-design-system-provider>
      <zero-tabs ${ref('tabs')} class="tabs" data-test-id="tabs">
        <span part="start" class="start" slot="start" data-test-id="reporting-tab">Reporting</span>
        <zero-tab id="list-reports" slot="tab" data-test-id="list-reports-tab">
          All Reports
        </zero-tab>
        <zero-tab id="create-edit-report" slot="tab" data-test-id="create-edit-report-tab">
          Create Report
        </zero-tab>
        ${when((x) => Object.keys(x.activeReport).length > 0, html `
            <zero-tab id="run-report" slot="tab" data-test-id="run-report-tab">Run Report</zero-tab>
          `)}

        <zero-tab-panel slot="tabpanel" class="tab-panel" data-test-id="list-reports-panel">
          ${header}
          <reporting-list ${ref('reportsGrid')} data-test-id="report-list"></reporting-list>
        </zero-tab-panel>

        <zero-tab-panel slot="tabpanel" class="tab-panel" data-test-id="create-edit-report-panel">
          <reporting-create-edit
            :report=${(x) => x.activeReport}
            :setPageTab=${(x) => x.setPageTab}
            :datasourceSettings=${(x) => x.datasourceSettings}
            data-test-id="create-edit-report-component"
          />
        </zero-tab-panel>
        ${when((x) => Object.keys(x.activeReport).length > 0, html `
            <zero-tab-panel slot="tabpanel" class="tab-panel" data-test-id="report-preview-panel">
              <reporting-preview
                :report=${(x) => x.activeReport}
                :datasourceSettings=${(x) => x.datasourceSettings}
                data-test-id="report-preview-component"
              />
            </zero-tab-panel>
          `)}
      </zero-tabs>
    </zero-design-system-provider>
  </div>
`;
